-- CaseCVX.lua
-- Script for Fendt Farmer 310/312 LSA
--
-- Author Rival renamed: Thomas0815
-- 05.01.2016
-- Version 1.1 @26.10.2016
	--> converted to FS17
-- Version 1.2 @05.11.2016
	--> added indoorsound change when door/windows are open
-- Version 1.3 @28.12.2016 edit DerFreddy7
	--> added Xerion Lenkrad sound
	--> added Xerion Cebis terminal Sound
-- Version 1.4 @23.01.2017 edit Thomas0815
	--> changes for CaseCVX
	
CaseCVX = {};

function CaseCVX.prerequisitesPresent(specializations)
    return true;
end;

function CaseCVX:load(savegame)
    self.blinkerLight0 = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.CaseCVXDisplay.blinkerLight#index0"));
    self.blinkerLight1 = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.CaseCVXDisplay.blinkerLight#index1"));
    self.blinkerLight2 = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.CaseCVXDisplay.blinkerLight#index2"));
    self.warnBlinkLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.CaseCVXDisplay.warnBlinkLight#index"));
    setVisibility(self.blinkerLight0, false);
    setVisibility(self.blinkerLight1, false);
    setVisibility(self.blinkerLight2, false);
    self.hasAttachedTrailers = 0;
	
	self.soundAdj = {};
	local i=0;
    while true do
        local key = string.format("vehicle.indoorsoundAdjustment.animation(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        local animName = getXMLString(self.xmlFile, key.."#name");
        local lowpassGain = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#lowpassGain"), 0.5);
        local volumeFactor = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#volumeFactor"), 0.5);
		self.soundAdj[i] = {};
		self.soundAdj[i].animName = animName;
		self.soundAdj[i].volumeFactor = volumeFactor;
		self.soundAdj[i].lowpassGain = lowpassGain;
        i = i +1;
    end;
	
	if self.isClient then
		self.sampleOpenDoorleftDoor = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Case_Puma_Sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorleftDoor = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Case_Puma_Sounds/tuer_zu2.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorrightDoor = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Case_Puma_Sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorrightDoor = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Case_Puma_Sounds/tuer_zu2.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenbackWindow = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Case_Puma_Sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleClosebackWindow = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Case_Puma_Sounds/tuer_zu.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenroof = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "Case_Puma_Sounds/tuer_auf.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseroof = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "Case_Puma_Sounds/tuer_zu.wav", self.baseDirectory, self.components[1].node);
	end;
end;

--function CaseCVX:postLoad(savegame)
--	for k,v in pairs(self.sampleMotor) do print(k,v) end
--end;

function CaseCVX:delete()
	if self.sampleOpenDoorleftDoor ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorleftDoor);
	end;
	if self.sampleOpenDoorrightDoor ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorrightDoor);
	end;
	if self.sampleOpenbackWindow ~= nil then
		SoundUtil.deleteSample(self.sampleOpenbackWindow);
	end;
	if self.sampleOpenroof ~= nil then
		SoundUtil.deleteSample(self.sampleOpenroof);
	end;
	if self.sampleCloseDoorleftDoor ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorleftDoor);
	end;
	if self.sampleCloseDoorrightDoor ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorrightDoor);
	end;
	if self.sampleClosebackWindow ~= nil then
		SoundUtil.deleteSample(self.sampleClosebackWindow);
	end;
	if self.sampleCloseroof ~= nil then
		SoundUtil.deleteSample(self.sampleCloseroof);
	end;
	
end;

function CaseCVX:mouseEvent(posX, posY, isDown, isUp, button)
end;

function CaseCVX:keyEvent(unicode, sym, modifier, isDown)
end;

function CaseCVX:update(dt)
    if self:getIsActive() and self.isClient then
        if table.getn(self.attachedImplements) > 0 or self.hasAttachedTrailers > 0 then
            self.hasAttachedTrailers = 0;
            for i=1, table.getn(self.attachedImplements) do  
                if self.attachedImplements[i].object.hasTurnLights and self.attachedImplements[i].object.hasTurnLights then 
                    self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
                end;
                if table.getn(self.attachedImplements[i].object.attachedImplements) > 0 then
                    for r=1, table.getn(self.attachedImplements[i].object.attachedImplements) do
                        if self.attachedImplements[i].object.attachedImplements[r].object.hasTurnLights and self.attachedImplements[i].object.attachedImplements[r].object.hasTurnLights then
                            self.hasAttachedTrailers = self.hasAttachedTrailers + 1;
                        end;
                    end;
                end;
            end;
        end;
        if self.hasAttachedTrailers == 0 then
            setVisibility(self.blinkerLight0, self.turnLightState ~= Lights.TURNLIGHT_OFF);
            setVisibility(self.blinkerLight1, false);
            setVisibility(self.blinkerLight2, false);
        elseif self.hasAttachedTrailers == 1 then
            setVisibility(self.blinkerLight0, self.turnLightState ~= Lights.TURNLIGHT_OFF);
            setVisibility(self.blinkerLight1, self.turnLightState ~= Lights.TURNLIGHT_OFF);
            setVisibility(self.blinkerLight2, false);
        elseif self.hasAttachedTrailers == 2 then
            setVisibility(self.blinkerLight0, self.turnLightState ~= Lights.TURNLIGHT_OFF);
            setVisibility(self.blinkerLight1, self.turnLightState ~= Lights.TURNLIGHT_OFF);
            setVisibility(self.blinkerLight2, self.turnLightState ~= Lights.TURNLIGHT_OFF);
        end;
        if self.turnLightState == Lights.TURNLIGHT_HAZARD then
            setVisibility(self.warnBlinkLight, true);
        else
            setVisibility(self.warnBlinkLight, false);
        end;
		if self.isEntered then
			if self:getIsAnimationPlaying("leftDoor") and self:getIsActiveForSound() then
				if self.animations["leftDoor"].currentSpeed > 0 and self.animations["leftDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorleftDoor, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorleftDoor,1,1,nil);
					end;
				elseif self.animations["leftDoor"].currentSpeed < 0 and self.animations["leftDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorleftDoor, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorleftDoor,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("rightDoor") and self:getIsActiveForSound() then
				if self.animations["rightDoor"].currentSpeed > 0 and self.animations["rightDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorrightDoor, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorrightDoor,1,1,nil);
					end;
				elseif self.animations["rightDoor"].currentSpeed < 0 and self.animations["rightDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorrightDoor, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorrightDoor,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("backWindow") and self:getIsActiveForSound() then
				if self.animations["backWindow"].currentSpeed > 0 and self.animations["backWindow"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenbackWindow, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenbackWindow,1,1,nil);
					end;
				elseif self.animations["backWindow"].currentSpeed < 0 and self.animations["backWindow"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleClosebackWindow, 1.5*dt) then
						SoundUtil.playSample(self.sampleClosebackWindow,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("roof") and self:getIsActiveForSound() then
				if self.animations["roof"].currentSpeed > 0 and self.animations["roof"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenroof, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenroof,1,1,nil);
					end;
				elseif self.animations["roof"].currentSpeed < 0 and self.animations["roof"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseroof, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseroof,1,1,nil);
					end;
				end;
			end;
			
			local sound=false;
			for i=0, #self.soundAdj do
				if self.animations[self.soundAdj[i].animName] ~= nil and self.animations[self.soundAdj[i].animName].currentTime > 500 then
					self.sampleMotor.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotor.indoorVolumeFactor);
					self.sampleMotor.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotor.indoorLowpassGain);
					self.sampleMotorStart.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStart.indoorVolumeFactor);
					self.sampleMotorStart.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStart.indoorLowpassGain);
					self.sampleMotorStop.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStop.indoorVolumeFactor);
					self.sampleMotorStop.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStop.indoorLowpassGain);
					
					self.sampleMotorRun.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorRun.indoorVolumeFactor);
					self.sampleMotorRun.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorRun.indoorLowpassGain);
					self.sampleMotorLoad.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorLoad.indoorVolumeFactor);
					self.sampleMotorLoad.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorLoad.indoorLowpassGain);
					sound=true;
				else
					if not sound then
						self.sampleMotor.indoorVolumeFactor = 0.55;
						self.sampleMotor.indoorLowpassGain = 0.2;
						self.sampleMotorStart.indoorVolumeFactor = 0.55;
						self.sampleMotorStart.indoorLowpassGain = 0.2;
						self.sampleMotorStop.indoorVolumeFactor = 0.55;
						self.sampleMotorStop.indoorLowpassGain = 0.2;
						
						self.sampleMotorRun.indoorVolumeFactor = 0.7;
						self.sampleMotorRun.indoorLowpassGain = 0.4;
						self.sampleMotorLoad.indoorVolumeFactor = 0.7;
						self.sampleMotorLoad.indoorLowpassGain = 0.4;
					end;
				end;
			end;
			SoundUtil.onCameraSwitched(self.activeCamera.isInside);
		end;
    end;
end;
function CaseCVX:updateTick(dt)
end;
function CaseCVX:draw()    
end;